@@ -1,4 +1,5 @@
 from abc import ABC, abstractmethod
+import secrets
 
 class StoreBase(ABC):
     """
@@ -8,6 +9,10 @@ class StoreBase(ABC):
         self._store = store
         self._validate_store()
     
+    def generate_key(self):
+        # https://docs.python.org/3/library/secrets.html
+        return secrets.token_urlsafe(32)
+    
     @abstractmethod
     def _validate_store(self):
         ...
